/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvControlBinop.h"
#include "HvSignalEnvelope.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_Iw2xByEx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nr69qoj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GOA5UwD1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0nv2D8jE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NFjEvvy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LR4ZoSOo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RKNh1XUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U0i2B9Iw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BKeDWOBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fxkiJq52_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YHx0bVK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sMAG0y0l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PBhfuJdR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vabyJzPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HHPFw2ZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YDeQggF1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YCbGicVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZgTvlcbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KrNYgQbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E68j1GGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ayzXY4IP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Giac9akq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_IIyqG1Rb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ifiQVATj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P3rQmlDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d6DmNwv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lJg825lB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2olbBQ2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vtcSTj9M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WQQR6vud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BGYua3Eg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_r9Eh97Fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YC0Mdrtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IqGHaPIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W6e9Da8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fDbuwSP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ECdzAQDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mFGWQTR9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yOlLddEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iXCgOwhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BgA6oQlW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WFF4GV8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_49CPeaRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_w1jSJ4E0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WnYZZHWw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_U8aZd4m2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QprOux8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ob3ze9OM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hw859nUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d6tPFgSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NuZUNrsO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7UU9cmj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kJoJcpQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3pjlcit0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ififUWH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jMcfcuzz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qk4f9197_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vBVFcqIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3umv46hb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_sxfV2XzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qswyo9jQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CmqDBIGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sXE0gs7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tirXPqX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_InByX2L0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WaP1CAnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KbDC0L2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NxufMh1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vMrvWOs4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hBS5AgiF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EsLBip3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zlu80Wkt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ug67v44v_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_XXcKiaKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UnKm9UyR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j8hOoR1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9WTzutNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4b1r4Yvi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3XAZw3Jo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0dS0vuS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ONiy2kvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VVuUH9Dk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nnf2Tznf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H1M6hKFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ax2KmIi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SgN5foGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bA5MaHIF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_jMUth7hQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4pcOnCuq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iiLe1jUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EVhouLxT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k8ArNlkd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qk3XOWnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HsVX5Ltn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mw5Yj1SJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WpvIHpsb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mipo8uNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XDOpM3Ox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_57Dl7YkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SbwwCEOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_66m0Gzs3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_pJaWeMtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SJTVtr1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3oKF7Qd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YXgLdRYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s4HHlEzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UfDsi9H7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jHnbpsAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U9kCrR8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C1hiZKTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2UqnJTB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QzigKajC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dBB6cF8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EcyIu0oC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_R3JPbxSU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ps8BOsfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0fdaWBg7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IvcZk7XZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tmFGeyul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vep0YVl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GLpOiA0u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hCt8TARt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NOA8FEMe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JPvIRsab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eQyUcrgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Iim9bzmh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_B5a0DHb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_d2jwtMKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ewbbz6YY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_2Vt7fZqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pBQPkjxH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oxuWRfcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Za0pp5Au_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RlOL7Zje_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GyMv0gfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aj9MtI7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_21hEue9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A9TxrMlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jsDZZ4xP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F3NSnzcD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PshQEMI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OdGfox8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AFhrAUly_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_0c9Ct6Cx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_czEMUZDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KTq4jG2B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YvLtinN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v41DXVV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sNk057G7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FF9kIqWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jya3uDKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ajQJ4zSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wnUkLErZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MeS4siYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K9u0JkcY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HwAUJVko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ThYPdvsi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_45JQ2xaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1gLvGHhx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZvHeU3KC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6l7tpoNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nxr78oMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZppSawqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eBkpboaK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iblzmPRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9bYjZ2g0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vTkD9ONa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dVdGC8CE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_T4PsKIX9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ph3PtKAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_H9EmMmfd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_iYTcBW4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_10hCVWKk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u6FzCCtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IombDJNg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eRNipx4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ouUggYwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_72OZLgad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_09RTAixI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9sooJXzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yoiE0VPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BG9x4FYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3c4sngoe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ztY6V9rj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3hwNYUMV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_hAN8i8fx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SiWF3Ggb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qHKVVE6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iEJGD8Pc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JKr0NM7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OUaOwQvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_98Y5NVsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b4xrg50R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q7PDdUVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1ESBRAvO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T2DnIq8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z6bfqVrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Qde9Nz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TfAqAR83_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OWqjmIea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yyerLDJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8vRRnYhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hlheL1RM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SxGOTwOZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PXFDEHCo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lv3V86zp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FyWtIMcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6NTQE9kc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ci66TjLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qrs4imZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OLci3Fuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oatlBZfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nyiQvqz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LVTis2LF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_syrvaXGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4RSvUuNY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pe7MLnM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9S11Utpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jhx15h2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_asA4brR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nu0nJl06_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xH8iemen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WuP1wZD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HVirvI4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k4bWekOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KlVvkGfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZcO2rzWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t02TMW1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cXyRxAFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TiTWfVCI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HrtLgUVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J9gqxuCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bf20hACa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6SS8URSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mvX7NR1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fKosI8v3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sGm7I4Tr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wVGx5juH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N3fyJ2DN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dBVOOs5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xiI9VBKw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Pn5oFlVx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_0Y7lPkw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_R0WM5vhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qKJAVm1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vK2jg8SF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Mem5v5gz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NNlttlXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GUGEOb6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_05HgwUE2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Ch9781rf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V9lSIWSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hCMG7tAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sIwRCxA8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9Cl8XuZf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w84mzJw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZX6ioy8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nA6m6O44_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SgAQaSWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fxss0hcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZyHRvSsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jhAUshAh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_8jvR1i5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_buIIAgOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5jbVHi7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wHuQ7lUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xFwGNIe2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TWhc6F7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_hZ6BEeGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_GcQWZyl5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8XuK2Tpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dCAA7d00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HGqtcT6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uqBkatbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8z6WrYnA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GaY7dchm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fNqDd3G9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_duaTTFj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4B0fvkke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TT7BJqlq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0skkuDTc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yzMt6c2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t5eiY2ub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fkLpmsiQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Yup4ctx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f8l25lBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zlNMKSPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P2BKRnhz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YzpqLdtZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d8O0a8Rg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8QDiETsR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qO2DuGah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V5NjLVit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xo0MnJAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WWhf5UFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nr35FRUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_78mJOdvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IXWE0Jtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2G4iN8Ng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QiLLkxxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HIwL7ljV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_x4f6K95Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tv0cBKRx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dX1jP0M6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KTLso4rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hb8c5xxZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P4S8poqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y4NNyDdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Yh9sxxNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0zEXeEwn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_I414hOMG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hUzz1oDx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qJiJZxIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aMrVQX39_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kQV9KJzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ws4C8tZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FrBVoZHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nE8jwVrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7BKEPEbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_83azqlIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3jrVOdgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_exxXP2CJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rROFvAMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_10OUnm5K_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1ia9HI8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hv70rrem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hkIA27PF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6W3p9qRh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ht6zpxTs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8l9Fyxgh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CQjJOVZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FipIsiqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kIf0xoap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fI2mMZy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iQaB6Siy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2KYvQ741_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Y3pPJ2CL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MrwEJ5mV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_jEoE4asv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P12MdoeN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kXUOCVsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FqAT2r4G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2CWNgTFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SlqkjJSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uLHLcAxQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zmpCfoGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zKjL0gZ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SOTrpS6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I92vb2c3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tQNV46Iq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BnBUCRmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Xnv3c97B_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_9FpnctNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OoSmUw4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M0lQVCnV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7sdtjjly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z0WagGna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A74nT1WC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6wW0daqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gm15frF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UK8ywk6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BDSjedZg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uMOQwUHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lkx59iKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ibkkbvHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hQkSaQNr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_xiWAeH5v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1NRc7SeW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_udpsHcAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_38ozxD3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wFcnLzoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zv1eJ169_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CNI3FZdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cjzfhgHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LL7Y9myl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kTTjS8Ms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cK74eulT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_prNeklbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yMiHI3kp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qk2JPdta_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tsDidRkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UbN0gFz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XALwLwNL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IEtEoShf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VzfAZ9EY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KZiZyRGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0cTTWeyh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FZO5uNzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e98GtwXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nn76nmBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qpIXmshY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qBW2bReB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sRIgef0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WZkBK3R3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7t5sV2lW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_askXBiDG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5dtkLoKR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nysHRKwl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rh9L5thN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dYvxchEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lm9uYTmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0YhtJcwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s7ssiVY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rR5K25JX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OKtjnQ4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_O3Ae2oNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1dqQOWsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tocxwf3s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dSx5CFXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WAPYDNBP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WgJGe5wo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kG6apA6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vYOZgomZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hMpf20cJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zpqLCnlw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wKyY6WJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ePFGcaMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kjqQhdym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_izDNV1Hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kC6ZF9Cl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fnXVVnck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_n4ymOJS9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_EV0jOOc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oqA7kcYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eWnoAbth_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sc2AVXG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n2uiNqh5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_27bBLwDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0rR0ZkxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z7LFTuk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S5B5kz2p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1ipgndOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dGNSvG89_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8bko2MCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sCcdTyzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NGzNRxKP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ck9zvOWa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qGokgN6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a5HxAGxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ys3q1jif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R4Oc9YsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gsR5CDAI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VxF06L2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7L7gQ3me_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zx8INiyV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sR9gk6pp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3FIENGQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NiiTqaH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6vPoIKop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OSjdg3HC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JjCFpnrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aLVX85ez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LZtH6au5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XRfoscdO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LR7nCCVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z3eN3I7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JqGkLjSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vFJOoqTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XV7xnygX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qXRjerv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WXTSRAAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AeYVTHY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zx9mxmqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7dc9CECk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_DP7nRLf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TtCSnrkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R1MwX4GW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JopVKxi5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cyUPRF8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KIjE4D4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_67NSwvy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s56VV0P2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DGEOiy2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_84oMzxQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AP0VMoLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zb4vsfnj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mCfQ62NG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GrD9qRrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UNH2l4on_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WariCidQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZNFL22wz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4VSeD8gN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q21PUuQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vToEmxNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Yx1z1Ga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e8t0Jqap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TOpLKPis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yJdbgqTR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bLHoKwtK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vk8Anvor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X89WeZFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VnCXDIqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DahWNv8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7U4qb3ew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T7EqrIrD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zkTlqjNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1DSK571h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AoGfayvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eQ4nwVeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KbENV0lv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_88a2xinh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sro3ydn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e7r8BXl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XCriiTUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1nDUHrNb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mLF0w4o2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KcBaw1xW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SuvKgQmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MuhJ5f8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AGquwsjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8g0O89lR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ln0kBbUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DefwmKF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lHbi9zkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S5JWJUO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MHEMwD7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YVXWoL8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bXmfKmhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zNPWMEQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6KaNLRCB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NJWbcgMk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TQ1g076G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VjGLpYnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Rq1X7MAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IRYBcRIp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_k1rogUTI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AmjluGZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8QEwCRck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mx1uw2Lw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7HuvFQJW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_StdK4x6M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2kjNdqlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Sy0V3NOi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_v3noEVM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pfWqiiht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iy1QL65f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BULKVfGB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_IgGf7JC9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PcNy5saT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mnLI2i4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CkfZrj7U_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_9buI2Jv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T8qeYYNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EpbhQgYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SOsLxY8P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PKFkXslv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Hsfg0nhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_VWutT7Sg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_mxEwZxcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RlMfDkiK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f8hCE4ah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MOD70his_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5UTDoS5y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xKzCkn2F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oew6PPGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_07MxuKmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wsqnaVAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bjuwQ4zc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yBcJa66o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yuzj7IfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fs0SPmX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zMTsUCGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0ipjyie1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4ulwkrSU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zlyVeeTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5BBkdpkc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MvdJgAg1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dmJBdCMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4LXB6YFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aU0CItUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fsnHPyrz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xzgqLwFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jcdoX8gL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ywOE4LHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtdCghxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xjyEf9Ls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f0AhaWig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4IPIu9LD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Nwo2M8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j9S88t6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9bKKlrOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KuOsJ6V2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ggv2Mwr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bAqLpD8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DY0yxwek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7x4lS1We_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Que0Z7jM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7bMhi3KP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QRWDt2ub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ll2PUTYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rn5HZ7U3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0EXezegB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RIDcyZel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8jhkGuqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Vq213T30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_F7LHr8Rk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ohxPTldk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6SWlUiNW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UXKUOMBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_w3wNuyhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fuA4Ihjl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XL4ZJjT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ystMSJhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WM1kRosu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Pj7Pxvn3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AQVAE84k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gd5qE81e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Jdk32CbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_71dRqySV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eolSktLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cJXugHDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BeqylVJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_H7kMEkCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DzRtXQ1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_ZedT4dfA;
  SignalLine sLine_OelE5ZIq;
  SignalLine sLine_V1awk77X;
  SignalLine sLine_xTHm8405;
  SignalLine sLine_0S8PHxDj;
  SignalLine sLine_7dMwlPgM;
  SignalLine sLine_bOI8r0Fb;
  SignalLine sLine_hKzntOW2;
  SignalLine sLine_fK0ZAw2E;
  SignalLine sLine_44b8sFzs;
  SignalLine sLine_laRLDJZs;
  SignalLine sLine_bgQ3dpax;
  SignalEnvelope sEnv_hZ6BEeGo;
  SignalEnvelope sEnv_GcQWZyl5;
  SignalLine sLine_H9nsWpah;
  SignalLine sLine_xmS7vKFk;
  SignalLine sLine_0IZD9JfQ;
  SignalLine sLine_79gXzz0V;
  SignalLine sLine_lwZXpMjt;
  SignalLine sLine_any1DhN1;
  SignalLine sLine_SxmvnFWt;
  SignalLine sLine_7YdlIHTh;
  SignalLine sLine_vUsIeJ7q;
  SignalLine sLine_fPNPJGyW;
  SignalLine sLine_xuZ16xNZ;
  SignalLine sLine_4ue4lSvF;
  SignalLine sLine_bUY08gbB;
  SignalLine sLine_bHnKG48Q;
  SignalLine sLine_rW4YH5IE;
  SignalLine sLine_0V9kHPtS;
  SignalLine sLine_02VYzb7P;
  SignalLine sLine_RLpu6t2M;
  SignalEnvelope sEnv_VWutT7Sg;
  SignalEnvelope sEnv_mxEwZxcw;
  SignalLine sLine_dyoGFs8w;
  SignalLine sLine_W4e98D1u;
  SignalLine sLine_pGF5NdiP;
  SignalLine sLine_9PnsaXLK;
  SignalLine sLine_AaWbo4ff;
  SignalLine sLine_q4idMazn;
  SignalLine sLine_zn5jNzhS;
  SignalLine sLine_uzbIycN0;
  ControlVar cVar_Iw2xByEx;
  ControlBinop cBinop_Nr69qoj8;
  ControlBinop cBinop_GOA5UwD1;
  ControlBinop cBinop_0nv2D8jE;
  ControlBinop cBinop_NFjEvvy5;
  ControlBinop cBinop_U0i2B9Iw;
  ControlBinop cBinop_fxkiJq52;
  ControlBinop cBinop_YHx0bVK3;
  ControlBinop cBinop_sMAG0y0l;
  ControlVar cVar_PBhfuJdR;
  ControlVar cVar_vabyJzPM;
  ControlVar cVar_HHPFw2ZR;
  ControlVar cVar_YDeQggF1;
  ControlVar cVar_YCbGicVQ;
  ControlBinop cBinop_ZgTvlcbl;
  ControlVar cVar_E68j1GGs;
  ControlVar cVar_ayzXY4IP;
  ControlIf cIf_vtcSTj9M;
  ControlIf cIf_WQQR6vud;
  ControlDelay cDelay_r9Eh97Fw;
  ControlBinop cBinop_W6e9Da8r;
  ControlBinop cBinop_fDbuwSP7;
  ControlIf cIf_49CPeaRI;
  ControlIf cIf_w1jSJ4E0;
  ControlDelay cDelay_U8aZd4m2;
  ControlBinop cBinop_hw859nUI;
  ControlBinop cBinop_d6tPFgSV;
  ControlIf cIf_qk4f9197;
  ControlIf cIf_vBVFcqIg;
  ControlDelay cDelay_sxfV2XzO;
  ControlBinop cBinop_sXE0gs7f;
  ControlBinop cBinop_tirXPqX8;
  ControlIf cIf_EsLBip3A;
  ControlIf cIf_zlu80Wkt;
  ControlDelay cDelay_XXcKiaKf;
  ControlBinop cBinop_9WTzutNe;
  ControlBinop cBinop_4b1r4Yvi;
  ControlIf cIf_Ax2KmIi4;
  ControlIf cIf_SgN5foGb;
  ControlDelay cDelay_jMUth7hQ;
  ControlBinop cBinop_EVhouLxT;
  ControlBinop cBinop_k8ArNlkd;
  ControlIf cIf_57Dl7YkK;
  ControlIf cIf_SbwwCEOV;
  ControlDelay cDelay_pJaWeMtB;
  ControlBinop cBinop_YXgLdRYb;
  ControlBinop cBinop_s4HHlEzM;
  ControlIf cIf_dBB6cF8h;
  ControlIf cIf_EcyIu0oC;
  ControlDelay cDelay_Ps8BOsfd;
  ControlBinop cBinop_tmFGeyul;
  ControlBinop cBinop_Vep0YVl8;
  ControlIf cIf_B5a0DHb7;
  ControlIf cIf_d2jwtMKP;
  ControlDelay cDelay_2Vt7fZqE;
  ControlBinop cBinop_Za0pp5Au;
  ControlBinop cBinop_RlOL7Zje;
  ControlIf cIf_PshQEMI6;
  ControlIf cIf_OdGfox8k;
  ControlDelay cDelay_0c9Ct6Cx;
  ControlBinop cBinop_YvLtinN8;
  ControlBinop cBinop_v41DXVV7;
  ControlIf cIf_K9u0JkcY;
  ControlIf cIf_HwAUJVko;
  ControlDelay cDelay_45JQ2xaM;
  ControlBinop cBinop_6l7tpoNs;
  ControlBinop cBinop_Nxr78oMl;
  ControlIf cIf_T4PsKIX9;
  ControlIf cIf_Ph3PtKAE;
  ControlDelay cDelay_iYTcBW4q;
  ControlBinop cBinop_IombDJNg;
  ControlBinop cBinop_eRNipx4z;
  ControlIf cIf_3c4sngoe;
  ControlIf cIf_ztY6V9rj;
  ControlDelay cDelay_hAN8i8fx;
  ControlBinop cBinop_iEJGD8Pc;
  ControlBinop cBinop_JKr0NM7n;
  SignalVarf sVarf_9CcLSjVF;
  SignalVarf sVarf_BuaMkvST;
  SignalVarf sVarf_eUg5J4Cx;
  SignalVarf sVarf_MQDKBrt1;
  SignalVarf sVarf_X3Wtv5Bn;
  SignalVarf sVarf_8Ehd4SL4;
  SignalVarf sVarf_96P43WAX;
  SignalVarf sVarf_6YSqWAWi;
  ControlVar cVar_xiI9VBKw;
  ControlSlice cSlice_0Y7lPkw7;
  ControlVar cVar_R0WM5vhA;
  ControlSlice cSlice_Mem5v5gz;
  ControlVar cVar_NNlttlXt;
  ControlSlice cSlice_Ch9781rf;
  ControlVar cVar_V9lSIWSh;
  ControlSlice cSlice_9Cl8XuZf;
  ControlVar cVar_w84mzJw1;
  ControlSlice cSlice_SgAQaSWG;
  ControlVar cVar_fxss0hcu;
  ControlDelay cDelay_8jvR1i5E;
  ControlVar cVar_wHuQ7lUt;
  ControlIf cIf_xFwGNIe2;
  ControlIf cIf_TWhc6F7g;
  ControlBinop cBinop_8XuK2Tpu;
  ControlBinop cBinop_HGqtcT6A;
  ControlBinop cBinop_uqBkatbH;
  ControlBinop cBinop_fNqDd3G9;
  ControlBinop cBinop_4B0fvkke;
  ControlSlice cSlice_Yup4ctx3;
  ControlVar cVar_f8l25lBk;
  SignalVarf sVarf_7RnU7Sxk;
  SignalVarf sVarf_aTGz6zaK;
  SignalVarf sVarf_vUV78xU0;
  SignalVarf sVarf_ZTiWCWGO;
  SignalVarf sVarf_a20U7JUW;
  SignalVarf sVarf_pWXaPSO2;
  ControlBinop cBinop_d8O0a8Rg;
  ControlBinop cBinop_78mJOdvn;
  ControlVar cVar_2G4iN8Ng;
  ControlVar cVar_QiLLkxxw;
  ControlIf cIf_y4NNyDdd;
  ControlIf cIf_Yh9sxxNt;
  ControlDelay cDelay_I414hOMG;
  ControlBinop cBinop_aMrVQX39;
  ControlBinop cBinop_kQV9KJzk;
  ControlIf cIf_exxXP2CJ;
  ControlIf cIf_rROFvAMz;
  ControlDelay cDelay_1ia9HI8J;
  ControlBinop cBinop_6W3p9qRh;
  ControlBinop cBinop_Ht6zpxTs;
  ControlIf cIf_2KYvQ741;
  ControlIf cIf_Y3pPJ2CL;
  ControlDelay cDelay_jEoE4asv;
  ControlBinop cBinop_FqAT2r4G;
  ControlBinop cBinop_2CWNgTFW;
  ControlIf cIf_tQNV46Iq;
  ControlIf cIf_BnBUCRmo;
  ControlDelay cDelay_9FpnctNC;
  ControlBinop cBinop_7sdtjjly;
  ControlBinop cBinop_z0WagGna;
  ControlIf cIf_lkx59iKc;
  ControlIf cIf_ibkkbvHM;
  ControlDelay cDelay_xiWAeH5v;
  ControlBinop cBinop_38ozxD3V;
  ControlBinop cBinop_wFcnLzoz;
  ControlIf cIf_prNeklbh;
  ControlIf cIf_yMiHI3kp;
  ControlDelay cDelay_tsDidRkU;
  ControlBinop cBinop_IEtEoShf;
  ControlBinop cBinop_VzfAZ9EY;
  ControlIf cIf_qBW2bReB;
  ControlIf cIf_sRIgef0h;
  ControlDelay cDelay_7t5sV2lW;
  ControlBinop cBinop_nysHRKwl;
  ControlBinop cBinop_Rh9L5thN;
  ControlIf cIf_O3Ae2oNa;
  ControlIf cIf_1dqQOWsS;
  ControlDelay cDelay_dSx5CFXq;
  ControlBinop cBinop_kG6apA6h;
  ControlBinop cBinop_vYOZgomZ;
  ControlIf cIf_kC6ZF9Cl;
  ControlIf cIf_fnXVVnck;
  ControlDelay cDelay_EV0jOOc4;
  ControlBinop cBinop_sc2AVXG5;
  ControlBinop cBinop_n2uiNqh5;
  ControlIf cIf_8bko2MCA;
  ControlIf cIf_sCcdTyzS;
  ControlDelay cDelay_Ck9zvOWa;
  ControlBinop cBinop_Ys3q1jif;
  ControlBinop cBinop_R4Oc9YsY;
  ControlIf cIf_NiiTqaH3;
  ControlIf cIf_6vPoIKop;
  ControlDelay cDelay_JjCFpnrn;
  ControlBinop cBinop_XRfoscdO;
  ControlBinop cBinop_LR7nCCVY;
  ControlIf cIf_AeYVTHY7;
  ControlIf cIf_zx9mxmqq;
  ControlDelay cDelay_DP7nRLf9;
  ControlBinop cBinop_JopVKxi5;
  ControlBinop cBinop_cyUPRF8G;
  SignalVarf sVarf_k5cJpGI3;
  SignalVarf sVarf_oy0ypEXO;
  SignalVarf sVarf_a10KTZ2X;
  SignalVarf sVarf_VIla07Rj;
  SignalVarf sVarf_ZR40llXo;
  SignalVarf sVarf_R6DjHrch;
  SignalVarf sVarf_uIwgTzQ6;
  SignalVarf sVarf_Qz5CfA9P;
  ControlVar cVar_6KaNLRCB;
  ControlSlice cSlice_TQ1g076G;
  ControlVar cVar_VjGLpYnU;
  ControlSlice cSlice_k1rogUTI;
  ControlVar cVar_AmjluGZ8;
  ControlSlice cSlice_7HuvFQJW;
  ControlVar cVar_StdK4x6M;
  ControlSlice cSlice_v3noEVM8;
  ControlVar cVar_pfWqiiht;
  ControlSlice cSlice_IgGf7JC9;
  ControlVar cVar_PcNy5saT;
  ControlDelay cDelay_9buI2Jv3;
  ControlVar cVar_SOsLxY8P;
  ControlIf cIf_PKFkXslv;
  ControlIf cIf_Hsfg0nhU;
  ControlBinop cBinop_RlMfDkiK;
  ControlBinop cBinop_MOD70his;
  ControlBinop cBinop_5UTDoS5y;
  ControlBinop cBinop_07MxuKmp;
  ControlBinop cBinop_bjuwQ4zc;
  ControlSlice cSlice_4ulwkrSU;
  ControlVar cVar_zlyVeeTe;
  SignalVarf sVarf_I6ORl4ul;
  SignalVarf sVarf_krkrSHvM;
  SignalVarf sVarf_9V0X997h;
  SignalVarf sVarf_UByJFqWu;
  SignalVarf sVarf_YskWwFYt;
  SignalVarf sVarf_DEeW7kdf;
  ControlBinop cBinop_4LXB6YFN;
  ControlBinop cBinop_xjyEf9Ls;
  ControlVar cVar_4IPIu9LD;
  SignalVarf sVarf_8Ix9ZFRe;
  SignalVarf sVarf_nwq4K5ct;
  SignalVarf sVarf_H9dQbnc0;
  SignalVarf sVarf_cPbAPxeD;
  ControlBinop cBinop_bAqLpD8d;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
