/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ZedT4dfA);
  numBytes += sLine_init(&sLine_OelE5ZIq);
  numBytes += sLine_init(&sLine_V1awk77X);
  numBytes += sLine_init(&sLine_xTHm8405);
  numBytes += sLine_init(&sLine_0S8PHxDj);
  numBytes += sLine_init(&sLine_7dMwlPgM);
  numBytes += sLine_init(&sLine_bOI8r0Fb);
  numBytes += sLine_init(&sLine_hKzntOW2);
  numBytes += sLine_init(&sLine_fK0ZAw2E);
  numBytes += sLine_init(&sLine_44b8sFzs);
  numBytes += sLine_init(&sLine_laRLDJZs);
  numBytes += sLine_init(&sLine_bgQ3dpax);
  numBytes += sEnv_init(&sEnv_hZ6BEeGo, 512, 256);
  numBytes += sEnv_init(&sEnv_GcQWZyl5, 512, 256);
  numBytes += sLine_init(&sLine_H9nsWpah);
  numBytes += sLine_init(&sLine_xmS7vKFk);
  numBytes += sLine_init(&sLine_0IZD9JfQ);
  numBytes += sLine_init(&sLine_79gXzz0V);
  numBytes += sLine_init(&sLine_lwZXpMjt);
  numBytes += sLine_init(&sLine_any1DhN1);
  numBytes += sLine_init(&sLine_SxmvnFWt);
  numBytes += sLine_init(&sLine_7YdlIHTh);
  numBytes += sLine_init(&sLine_vUsIeJ7q);
  numBytes += sLine_init(&sLine_fPNPJGyW);
  numBytes += sLine_init(&sLine_xuZ16xNZ);
  numBytes += sLine_init(&sLine_4ue4lSvF);
  numBytes += sLine_init(&sLine_bUY08gbB);
  numBytes += sLine_init(&sLine_bHnKG48Q);
  numBytes += sLine_init(&sLine_rW4YH5IE);
  numBytes += sLine_init(&sLine_0V9kHPtS);
  numBytes += sLine_init(&sLine_02VYzb7P);
  numBytes += sLine_init(&sLine_RLpu6t2M);
  numBytes += sEnv_init(&sEnv_VWutT7Sg, 512, 256);
  numBytes += sEnv_init(&sEnv_mxEwZxcw, 512, 256);
  numBytes += sLine_init(&sLine_dyoGFs8w);
  numBytes += sLine_init(&sLine_W4e98D1u);
  numBytes += sLine_init(&sLine_pGF5NdiP);
  numBytes += sLine_init(&sLine_9PnsaXLK);
  numBytes += sLine_init(&sLine_AaWbo4ff);
  numBytes += sLine_init(&sLine_q4idMazn);
  numBytes += sLine_init(&sLine_zn5jNzhS);
  numBytes += sLine_init(&sLine_uzbIycN0);
  numBytes += cVar_init_f(&cVar_Iw2xByEx, 0.0f);
  numBytes += cVar_init_f(&cVar_PBhfuJdR, 0.0f);
  numBytes += cVar_init_f(&cVar_vabyJzPM, 0.0f);
  numBytes += cVar_init_f(&cVar_HHPFw2ZR, 0.0f);
  numBytes += cVar_init_f(&cVar_YDeQggF1, 0.0f);
  numBytes += cVar_init_f(&cVar_YCbGicVQ, 1.0f);
  numBytes += cVar_init_f(&cVar_E68j1GGs, 0.0f);
  numBytes += cVar_init_f(&cVar_ayzXY4IP, 0.0f);
  numBytes += cIf_init(&cIf_vtcSTj9M, false);
  numBytes += cIf_init(&cIf_WQQR6vud, false);
  numBytes += cDelay_init(this, &cDelay_r9Eh97Fw, 10.0f);
  numBytes += cIf_init(&cIf_49CPeaRI, false);
  numBytes += cIf_init(&cIf_w1jSJ4E0, false);
  numBytes += cDelay_init(this, &cDelay_U8aZd4m2, 10.0f);
  numBytes += cIf_init(&cIf_qk4f9197, false);
  numBytes += cIf_init(&cIf_vBVFcqIg, false);
  numBytes += cDelay_init(this, &cDelay_sxfV2XzO, 10.0f);
  numBytes += cIf_init(&cIf_EsLBip3A, false);
  numBytes += cIf_init(&cIf_zlu80Wkt, false);
  numBytes += cDelay_init(this, &cDelay_XXcKiaKf, 10.0f);
  numBytes += cIf_init(&cIf_Ax2KmIi4, false);
  numBytes += cIf_init(&cIf_SgN5foGb, false);
  numBytes += cDelay_init(this, &cDelay_jMUth7hQ, 10.0f);
  numBytes += cIf_init(&cIf_57Dl7YkK, false);
  numBytes += cIf_init(&cIf_SbwwCEOV, false);
  numBytes += cDelay_init(this, &cDelay_pJaWeMtB, 10.0f);
  numBytes += cIf_init(&cIf_dBB6cF8h, false);
  numBytes += cIf_init(&cIf_EcyIu0oC, false);
  numBytes += cDelay_init(this, &cDelay_Ps8BOsfd, 10.0f);
  numBytes += cIf_init(&cIf_B5a0DHb7, false);
  numBytes += cIf_init(&cIf_d2jwtMKP, false);
  numBytes += cDelay_init(this, &cDelay_2Vt7fZqE, 10.0f);
  numBytes += cIf_init(&cIf_PshQEMI6, false);
  numBytes += cIf_init(&cIf_OdGfox8k, false);
  numBytes += cDelay_init(this, &cDelay_0c9Ct6Cx, 10.0f);
  numBytes += cIf_init(&cIf_K9u0JkcY, false);
  numBytes += cIf_init(&cIf_HwAUJVko, false);
  numBytes += cDelay_init(this, &cDelay_45JQ2xaM, 10.0f);
  numBytes += cIf_init(&cIf_T4PsKIX9, false);
  numBytes += cIf_init(&cIf_Ph3PtKAE, false);
  numBytes += cDelay_init(this, &cDelay_iYTcBW4q, 10.0f);
  numBytes += cIf_init(&cIf_3c4sngoe, false);
  numBytes += cIf_init(&cIf_ztY6V9rj, false);
  numBytes += cDelay_init(this, &cDelay_hAN8i8fx, 10.0f);
  numBytes += sVarf_init(&sVarf_9CcLSjVF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BuaMkvST, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eUg5J4Cx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MQDKBrt1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X3Wtv5Bn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8Ehd4SL4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_96P43WAX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6YSqWAWi, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xiI9VBKw, 0.0f);
  numBytes += cSlice_init(&cSlice_0Y7lPkw7, 1, -1);
  numBytes += cVar_init_f(&cVar_R0WM5vhA, 1.0f);
  numBytes += cSlice_init(&cSlice_Mem5v5gz, 1, -1);
  numBytes += cVar_init_f(&cVar_NNlttlXt, 0.0f);
  numBytes += cSlice_init(&cSlice_Ch9781rf, 1, -1);
  numBytes += cVar_init_f(&cVar_V9lSIWSh, 512.0f);
  numBytes += cSlice_init(&cSlice_9Cl8XuZf, 1, -1);
  numBytes += cVar_init_f(&cVar_w84mzJw1, 1.0f);
  numBytes += cSlice_init(&cSlice_SgAQaSWG, 1, -1);
  numBytes += cVar_init_f(&cVar_fxss0hcu, 1.0f);
  numBytes += cDelay_init(this, &cDelay_8jvR1i5E, 20.0f);
  numBytes += cVar_init_f(&cVar_wHuQ7lUt, 0.0f);
  numBytes += cIf_init(&cIf_xFwGNIe2, false);
  numBytes += cIf_init(&cIf_TWhc6F7g, false);
  numBytes += cBinop_init(&cBinop_8XuK2Tpu, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Yup4ctx3, 1, -1);
  numBytes += cVar_init_f(&cVar_f8l25lBk, 0.0f);
  numBytes += sVarf_init(&sVarf_7RnU7Sxk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aTGz6zaK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vUV78xU0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZTiWCWGO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a20U7JUW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pWXaPSO2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2G4iN8Ng, 0.0f);
  numBytes += cVar_init_f(&cVar_QiLLkxxw, 0.0f);
  numBytes += cIf_init(&cIf_y4NNyDdd, false);
  numBytes += cIf_init(&cIf_Yh9sxxNt, false);
  numBytes += cDelay_init(this, &cDelay_I414hOMG, 10.0f);
  numBytes += cIf_init(&cIf_exxXP2CJ, false);
  numBytes += cIf_init(&cIf_rROFvAMz, false);
  numBytes += cDelay_init(this, &cDelay_1ia9HI8J, 10.0f);
  numBytes += cIf_init(&cIf_2KYvQ741, false);
  numBytes += cIf_init(&cIf_Y3pPJ2CL, false);
  numBytes += cDelay_init(this, &cDelay_jEoE4asv, 10.0f);
  numBytes += cIf_init(&cIf_tQNV46Iq, false);
  numBytes += cIf_init(&cIf_BnBUCRmo, false);
  numBytes += cDelay_init(this, &cDelay_9FpnctNC, 10.0f);
  numBytes += cIf_init(&cIf_lkx59iKc, false);
  numBytes += cIf_init(&cIf_ibkkbvHM, false);
  numBytes += cDelay_init(this, &cDelay_xiWAeH5v, 10.0f);
  numBytes += cIf_init(&cIf_prNeklbh, false);
  numBytes += cIf_init(&cIf_yMiHI3kp, false);
  numBytes += cDelay_init(this, &cDelay_tsDidRkU, 10.0f);
  numBytes += cIf_init(&cIf_qBW2bReB, false);
  numBytes += cIf_init(&cIf_sRIgef0h, false);
  numBytes += cDelay_init(this, &cDelay_7t5sV2lW, 10.0f);
  numBytes += cIf_init(&cIf_O3Ae2oNa, false);
  numBytes += cIf_init(&cIf_1dqQOWsS, false);
  numBytes += cDelay_init(this, &cDelay_dSx5CFXq, 10.0f);
  numBytes += cIf_init(&cIf_kC6ZF9Cl, false);
  numBytes += cIf_init(&cIf_fnXVVnck, false);
  numBytes += cDelay_init(this, &cDelay_EV0jOOc4, 10.0f);
  numBytes += cIf_init(&cIf_8bko2MCA, false);
  numBytes += cIf_init(&cIf_sCcdTyzS, false);
  numBytes += cDelay_init(this, &cDelay_Ck9zvOWa, 10.0f);
  numBytes += cIf_init(&cIf_NiiTqaH3, false);
  numBytes += cIf_init(&cIf_6vPoIKop, false);
  numBytes += cDelay_init(this, &cDelay_JjCFpnrn, 10.0f);
  numBytes += cIf_init(&cIf_AeYVTHY7, false);
  numBytes += cIf_init(&cIf_zx9mxmqq, false);
  numBytes += cDelay_init(this, &cDelay_DP7nRLf9, 10.0f);
  numBytes += sVarf_init(&sVarf_k5cJpGI3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oy0ypEXO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a10KTZ2X, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VIla07Rj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZR40llXo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_R6DjHrch, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uIwgTzQ6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Qz5CfA9P, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6KaNLRCB, 0.0f);
  numBytes += cSlice_init(&cSlice_TQ1g076G, 1, -1);
  numBytes += cVar_init_f(&cVar_VjGLpYnU, 1.0f);
  numBytes += cSlice_init(&cSlice_k1rogUTI, 1, -1);
  numBytes += cVar_init_f(&cVar_AmjluGZ8, 0.0f);
  numBytes += cSlice_init(&cSlice_7HuvFQJW, 1, -1);
  numBytes += cVar_init_f(&cVar_StdK4x6M, 512.0f);
  numBytes += cSlice_init(&cSlice_v3noEVM8, 1, -1);
  numBytes += cVar_init_f(&cVar_pfWqiiht, 1.0f);
  numBytes += cSlice_init(&cSlice_IgGf7JC9, 1, -1);
  numBytes += cVar_init_f(&cVar_PcNy5saT, 1.0f);
  numBytes += cDelay_init(this, &cDelay_9buI2Jv3, 20.0f);
  numBytes += cVar_init_f(&cVar_SOsLxY8P, 0.0f);
  numBytes += cIf_init(&cIf_PKFkXslv, false);
  numBytes += cIf_init(&cIf_Hsfg0nhU, false);
  numBytes += cBinop_init(&cBinop_RlMfDkiK, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_4ulwkrSU, 1, -1);
  numBytes += cVar_init_f(&cVar_zlyVeeTe, 0.0f);
  numBytes += sVarf_init(&sVarf_I6ORl4ul, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_krkrSHvM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9V0X997h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UByJFqWu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YskWwFYt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DEeW7kdf, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4IPIu9LD, 0.0f);
  numBytes += sVarf_init(&sVarf_8Ix9ZFRe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nwq4K5ct, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H9dQbnc0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cPbAPxeD, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_hZ6BEeGo);
  sEnv_free(&sEnv_GcQWZyl5);
  sEnv_free(&sEnv_VWutT7Sg);
  sEnv_free(&sEnv_mxEwZxcw);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ohxPTldk_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w3wNuyhF_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DzRtXQ1W_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UXKUOMBa_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F7LHr8Rk_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fuA4Ihjl_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vq213T30_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8jhkGuqj_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WM1kRosu_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XL4ZJjT2_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gd5qE81e_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AQVAE84k_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ystMSJhY_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pj7Pxvn3_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eolSktLE_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jdk32CbN_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H7kMEkCV_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BeqylVJT_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_71dRqySV_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cJXugHDZ_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6SWlUiNW_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_Iw2xByEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KuOsJ6V2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_Nr69qoj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GOA5UwD1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GOA5UwD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_0nv2D8jE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0nv2D8jE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NFjEvvy5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NFjEvvy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LR4ZoSOo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RKNh1XUQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LR4ZoSOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U0i2B9Iw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RKNh1XUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BKeDWOBR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_U0i2B9Iw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YHx0bVK3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BKeDWOBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fxkiJq52_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fxkiJq52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sMAG0y0l_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YHx0bVK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Nwo2M8x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_sMAG0y0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j9S88t6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_PBhfuJdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9bKKlrOX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_vabyJzPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DY0yxwek_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_HHPFw2ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ggv2Mwr1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_YDeQggF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7x4lS1We_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_YCbGicVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZgTvlcbl_sendMessage);
  cMsg_Que0Z7jM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_ZgTvlcbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YCbGicVQ, 1, m, &cVar_YCbGicVQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KrNYgQbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7bMhi3KP_sendMessage(_c, 0, m);
  cMsg_QRWDt2ub_sendMessage(_c, 0, m);
  cMsg_Ll2PUTYv_sendMessage(_c, 0, m);
  cMsg_RIDcyZel_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_E68j1GGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2BKRnhz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_ayzXY4IP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YzpqLdtZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Giac9akq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IIyqG1Rb_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ifiQVATj_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P3rQmlDh_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d6DmNwv2_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lJg825lB_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2olbBQ2b_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_IIyqG1Rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z6bfqVrU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ifiQVATj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Qde9Nz6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_P3rQmlDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TfAqAR83_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_d6DmNwv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OWqjmIea_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_lJg825lB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yyerLDJ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_2olbBQ2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8vRRnYhg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_vtcSTj9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WFF4GV8g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_WQQR6vud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BgA6oQlW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_BGYua3Eg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YC0Mdrtq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YC0Mdrtq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_r9Eh97Fw, 1, m, &cDelay_r9Eh97Fw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IqGHaPIu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_r9Eh97Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_r9Eh97Fw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vtcSTj9M, 0, m, &cIf_vtcSTj9M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YC0Mdrtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_r9Eh97Fw, 0, m, &cDelay_r9Eh97Fw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IqGHaPIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_r9Eh97Fw, 0, m, &cDelay_r9Eh97Fw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_W6e9Da8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iXCgOwhM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yOlLddEl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fDbuwSP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ECdzAQDa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mFGWQTR9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ECdzAQDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vtcSTj9M, 1, m, &cIf_vtcSTj9M_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mFGWQTR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BGYua3Eg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_yOlLddEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WQQR6vud, 0, m, &cIf_WQQR6vud_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iXCgOwhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WQQR6vud, 1, m, &cIf_WQQR6vud_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BgA6oQlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xTHm8405, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_WFF4GV8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xTHm8405, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_49CPeaRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jMcfcuzz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_w1jSJ4E0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ififUWH0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_WnYZZHWw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QprOux8M_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QprOux8M_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_U8aZd4m2, 1, m, &cDelay_U8aZd4m2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ob3ze9OM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_U8aZd4m2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_U8aZd4m2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_49CPeaRI, 0, m, &cIf_49CPeaRI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QprOux8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_U8aZd4m2, 0, m, &cDelay_U8aZd4m2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ob3ze9OM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_U8aZd4m2, 0, m, &cDelay_U8aZd4m2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hw859nUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3pjlcit0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kJoJcpQr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_d6tPFgSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7UU9cmj8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NuZUNrsO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NuZUNrsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WnYZZHWw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_7UU9cmj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_49CPeaRI, 1, m, &cIf_49CPeaRI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kJoJcpQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w1jSJ4E0, 0, m, &cIf_w1jSJ4E0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3pjlcit0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w1jSJ4E0, 1, m, &cIf_w1jSJ4E0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ififUWH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bOI8r0Fb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jMcfcuzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bOI8r0Fb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_qk4f9197_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hBS5AgiF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_vBVFcqIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vMrvWOs4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3umv46hb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Qswyo9jQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Qswyo9jQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sxfV2XzO, 1, m, &cDelay_sxfV2XzO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CmqDBIGR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_sxfV2XzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sxfV2XzO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qk4f9197, 0, m, &cIf_qk4f9197_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Qswyo9jQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sxfV2XzO, 0, m, &cDelay_sxfV2XzO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CmqDBIGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sxfV2XzO, 0, m, &cDelay_sxfV2XzO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sXE0gs7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KbDC0L2N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NxufMh1o_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tirXPqX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_InByX2L0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WaP1CAnd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_InByX2L0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qk4f9197, 1, m, &cIf_qk4f9197_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WaP1CAnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3umv46hb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_KbDC0L2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vBVFcqIg, 1, m, &cIf_vBVFcqIg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NxufMh1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vBVFcqIg, 0, m, &cIf_vBVFcqIg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vMrvWOs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_44b8sFzs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_hBS5AgiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_44b8sFzs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_EsLBip3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H1M6hKFJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_zlu80Wkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nnf2Tznf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Ug67v44v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UnKm9UyR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UnKm9UyR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XXcKiaKf, 1, m, &cDelay_XXcKiaKf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j8hOoR1u_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_XXcKiaKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XXcKiaKf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EsLBip3A, 0, m, &cIf_EsLBip3A_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UnKm9UyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XXcKiaKf, 0, m, &cDelay_XXcKiaKf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_j8hOoR1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XXcKiaKf, 0, m, &cDelay_XXcKiaKf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_9WTzutNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VVuUH9Dk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ONiy2kvD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4b1r4Yvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0dS0vuS4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3XAZw3Jo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3XAZw3Jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ug67v44v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_0dS0vuS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EsLBip3A, 1, m, &cIf_EsLBip3A_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ONiy2kvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zlu80Wkt, 0, m, &cIf_zlu80Wkt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VVuUH9Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zlu80Wkt, 1, m, &cIf_zlu80Wkt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Nnf2Tznf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0S8PHxDj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_H1M6hKFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0S8PHxDj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Ax2KmIi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XDOpM3Ox_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_SgN5foGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mipo8uNq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bA5MaHIF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4pcOnCuq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4pcOnCuq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jMUth7hQ, 1, m, &cDelay_jMUth7hQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iiLe1jUt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_jMUth7hQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jMUth7hQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ax2KmIi4, 0, m, &cIf_Ax2KmIi4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4pcOnCuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMUth7hQ, 0, m, &cDelay_jMUth7hQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iiLe1jUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMUth7hQ, 0, m, &cDelay_jMUth7hQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EVhouLxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mw5Yj1SJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WpvIHpsb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_k8ArNlkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qk3XOWnb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HsVX5Ltn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Qk3XOWnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ax2KmIi4, 1, m, &cIf_Ax2KmIi4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HsVX5Ltn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bA5MaHIF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Mw5Yj1SJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SgN5foGb, 1, m, &cIf_SgN5foGb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WpvIHpsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SgN5foGb, 0, m, &cIf_SgN5foGb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mipo8uNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKzntOW2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XDOpM3Ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKzntOW2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_57Dl7YkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QzigKajC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_SbwwCEOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2UqnJTB6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_66m0Gzs3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SJTVtr1z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SJTVtr1z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pJaWeMtB, 1, m, &cDelay_pJaWeMtB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3oKF7Qd5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_pJaWeMtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pJaWeMtB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_57Dl7YkK, 0, m, &cIf_57Dl7YkK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SJTVtr1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pJaWeMtB, 0, m, &cDelay_pJaWeMtB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3oKF7Qd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pJaWeMtB, 0, m, &cDelay_pJaWeMtB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YXgLdRYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U9kCrR8k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C1hiZKTv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_s4HHlEzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jHnbpsAL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UfDsi9H7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UfDsi9H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_66m0Gzs3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_jHnbpsAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_57Dl7YkK, 1, m, &cIf_57Dl7YkK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_U9kCrR8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SbwwCEOV, 1, m, &cIf_SbwwCEOV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C1hiZKTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SbwwCEOV, 0, m, &cIf_SbwwCEOV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2UqnJTB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_laRLDJZs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QzigKajC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_laRLDJZs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_dBB6cF8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Iim9bzmh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_EcyIu0oC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eQyUcrgp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_R3JPbxSU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0fdaWBg7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0fdaWBg7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ps8BOsfd, 1, m, &cDelay_Ps8BOsfd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IvcZk7XZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Ps8BOsfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ps8BOsfd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dBB6cF8h, 0, m, &cIf_dBB6cF8h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0fdaWBg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ps8BOsfd, 0, m, &cDelay_Ps8BOsfd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IvcZk7XZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ps8BOsfd, 0, m, &cDelay_Ps8BOsfd_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tmFGeyul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NOA8FEMe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JPvIRsab_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Vep0YVl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hCt8TARt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GLpOiA0u_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GLpOiA0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_R3JPbxSU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hCt8TARt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dBB6cF8h, 1, m, &cIf_dBB6cF8h_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NOA8FEMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EcyIu0oC, 1, m, &cIf_EcyIu0oC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JPvIRsab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EcyIu0oC, 0, m, &cIf_EcyIu0oC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eQyUcrgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7dMwlPgM, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Iim9bzmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7dMwlPgM, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_B5a0DHb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F3NSnzcD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_d2jwtMKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jsDZZ4xP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Ewbbz6YY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pBQPkjxH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pBQPkjxH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2Vt7fZqE, 1, m, &cDelay_2Vt7fZqE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oxuWRfcH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_2Vt7fZqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2Vt7fZqE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_B5a0DHb7, 0, m, &cIf_B5a0DHb7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pBQPkjxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Vt7fZqE, 0, m, &cDelay_2Vt7fZqE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oxuWRfcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Vt7fZqE, 0, m, &cDelay_2Vt7fZqE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Za0pp5Au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_21hEue9v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A9TxrMlR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RlOL7Zje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GyMv0gfJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aj9MtI7K_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GyMv0gfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B5a0DHb7, 1, m, &cIf_B5a0DHb7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aj9MtI7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ewbbz6YY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_21hEue9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d2jwtMKP, 1, m, &cIf_d2jwtMKP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_A9TxrMlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d2jwtMKP, 0, m, &cIf_d2jwtMKP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jsDZZ4xP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fK0ZAw2E, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_F3NSnzcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fK0ZAw2E, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_PshQEMI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MeS4siYD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_OdGfox8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wnUkLErZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_AFhrAUly_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_czEMUZDE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_czEMUZDE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0c9Ct6Cx, 1, m, &cDelay_0c9Ct6Cx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KTq4jG2B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_0c9Ct6Cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0c9Ct6Cx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PshQEMI6, 0, m, &cIf_PshQEMI6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_czEMUZDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0c9Ct6Cx, 0, m, &cDelay_0c9Ct6Cx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KTq4jG2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0c9Ct6Cx, 0, m, &cDelay_0c9Ct6Cx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YvLtinN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ajQJ4zSF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jya3uDKO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_v41DXVV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sNk057G7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FF9kIqWM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sNk057G7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PshQEMI6, 1, m, &cIf_PshQEMI6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FF9kIqWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AFhrAUly_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Jya3uDKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OdGfox8k, 0, m, &cIf_OdGfox8k_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ajQJ4zSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OdGfox8k, 1, m, &cIf_OdGfox8k_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wnUkLErZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bgQ3dpax, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_MeS4siYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bgQ3dpax, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_K9u0JkcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dVdGC8CE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_HwAUJVko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vTkD9ONa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ThYPdvsi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1gLvGHhx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1gLvGHhx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_45JQ2xaM, 1, m, &cDelay_45JQ2xaM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZvHeU3KC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_45JQ2xaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_45JQ2xaM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_K9u0JkcY, 0, m, &cIf_K9u0JkcY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1gLvGHhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_45JQ2xaM, 0, m, &cDelay_45JQ2xaM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZvHeU3KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_45JQ2xaM, 0, m, &cDelay_45JQ2xaM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6l7tpoNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9bYjZ2g0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iblzmPRY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Nxr78oMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eBkpboaK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZppSawqy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZppSawqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ThYPdvsi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_eBkpboaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K9u0JkcY, 1, m, &cIf_K9u0JkcY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iblzmPRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HwAUJVko, 0, m, &cIf_HwAUJVko_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9bYjZ2g0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HwAUJVko, 1, m, &cIf_HwAUJVko_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vTkD9ONa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZedT4dfA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_dVdGC8CE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZedT4dfA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_T4PsKIX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BG9x4FYH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Ph3PtKAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yoiE0VPT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_H9EmMmfd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_10hCVWKk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_10hCVWKk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_iYTcBW4q, 1, m, &cDelay_iYTcBW4q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u6FzCCtt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_iYTcBW4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iYTcBW4q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_T4PsKIX9, 0, m, &cIf_T4PsKIX9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_10hCVWKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_iYTcBW4q, 0, m, &cDelay_iYTcBW4q_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_u6FzCCtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iYTcBW4q, 0, m, &cDelay_iYTcBW4q_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IombDJNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_09RTAixI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9sooJXzF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eRNipx4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ouUggYwP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_72OZLgad_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ouUggYwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T4PsKIX9, 1, m, &cIf_T4PsKIX9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_72OZLgad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_H9EmMmfd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_09RTAixI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ph3PtKAE, 1, m, &cIf_Ph3PtKAE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9sooJXzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ph3PtKAE, 0, m, &cIf_Ph3PtKAE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yoiE0VPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OelE5ZIq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BG9x4FYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OelE5ZIq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_3c4sngoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T2DnIq8b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ztY6V9rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1ESBRAvO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3hwNYUMV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SiWF3Ggb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SiWF3Ggb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hAN8i8fx, 1, m, &cDelay_hAN8i8fx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qHKVVE6N_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_hAN8i8fx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hAN8i8fx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3c4sngoe, 0, m, &cIf_3c4sngoe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SiWF3Ggb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hAN8i8fx, 0, m, &cDelay_hAN8i8fx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qHKVVE6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hAN8i8fx, 0, m, &cDelay_hAN8i8fx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iEJGD8Pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b4xrg50R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q7PDdUVb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JKr0NM7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OUaOwQvI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_98Y5NVsX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OUaOwQvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3c4sngoe, 1, m, &cIf_3c4sngoe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_98Y5NVsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3hwNYUMV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_b4xrg50R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ztY6V9rj, 1, m, &cIf_ztY6V9rj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_q7PDdUVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ztY6V9rj, 0, m, &cIf_ztY6V9rj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1ESBRAvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V1awk77X, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_T2DnIq8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V1awk77X, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_z6bfqVrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_ci66TjLl_sendMessage(_c, 0, m);
  cMsg_Jhx15h2r_sendMessage(_c, 0, m);
  cMsg_fKosI8v3_sendMessage(_c, 0, m);
  cMsg_cXyRxAFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8Qde9Nz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_ci66TjLl_sendMessage(_c, 0, m);
  cMsg_9S11Utpg_sendMessage(_c, 0, m);
  cMsg_sGm7I4Tr_sendMessage(_c, 0, m);
  cMsg_t02TMW1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TfAqAR83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_qrs4imZm_sendMessage(_c, 0, m);
  cMsg_9S11Utpg_sendMessage(_c, 0, m);
  cMsg_cXyRxAFQ_sendMessage(_c, 0, m);
  cMsg_dBVOOs5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_OWqjmIea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_qrs4imZm_sendMessage(_c, 0, m);
  cMsg_asA4brR2_sendMessage(_c, 0, m);
  cMsg_fKosI8v3_sendMessage(_c, 0, m);
  cMsg_ZcO2rzWV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_yyerLDJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_OLci3Fuh_sendMessage(_c, 0, m);
  cMsg_t02TMW1n_sendMessage(_c, 0, m);
  cMsg_N3fyJ2DN_sendMessage(_c, 0, m);
  cMsg_fKosI8v3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8vRRnYhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_OLci3Fuh_sendMessage(_c, 0, m);
  cMsg_ZcO2rzWV_sendMessage(_c, 0, m);
  cMsg_9S11Utpg_sendMessage(_c, 0, m);
  cMsg_wVGx5juH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hlheL1RM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fDbuwSP7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_W6e9Da8r_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SxGOTwOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fDbuwSP7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_W6e9Da8r_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PXFDEHCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d6tPFgSV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hw859nUI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Lv3V86zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d6tPFgSV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hw859nUI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FyWtIMcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tirXPqX8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sXE0gs7f_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6NTQE9kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tirXPqX8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sXE0gs7f_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ci66TjLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_hlheL1RM_sendMessage(_c, 0, m);
  cMsg_Lv3V86zp_sendMessage(_c, 0, m);
  cMsg_6NTQE9kc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qrs4imZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_SxGOTwOZ_sendMessage(_c, 0, m);
  cMsg_PXFDEHCo_sendMessage(_c, 0, m);
  cMsg_6NTQE9kc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_OLci3Fuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_SxGOTwOZ_sendMessage(_c, 0, m);
  cMsg_Lv3V86zp_sendMessage(_c, 0, m);
  cMsg_FyWtIMcg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oatlBZfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4b1r4Yvi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9WTzutNe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nyiQvqz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4b1r4Yvi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9WTzutNe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LVTis2LF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k8ArNlkd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EVhouLxT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_syrvaXGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k8ArNlkd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EVhouLxT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4RSvUuNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s4HHlEzM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YXgLdRYb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Pe7MLnM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s4HHlEzM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YXgLdRYb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9S11Utpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_nyiQvqz6_sendMessage(_c, 0, m);
  cMsg_syrvaXGn_sendMessage(_c, 0, m);
  cMsg_Pe7MLnM8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Jhx15h2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_nyiQvqz6_sendMessage(_c, 0, m);
  cMsg_LVTis2LF_sendMessage(_c, 0, m);
  cMsg_4RSvUuNY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_asA4brR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_oatlBZfY_sendMessage(_c, 0, m);
  cMsg_syrvaXGn_sendMessage(_c, 0, m);
  cMsg_4RSvUuNY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Nu0nJl06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Nxr78oMl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6l7tpoNs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xH8iemen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Nxr78oMl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6l7tpoNs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WuP1wZD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eRNipx4z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IombDJNg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HVirvI4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eRNipx4z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IombDJNg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_k4bWekOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JKr0NM7n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iEJGD8Pc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KlVvkGfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JKr0NM7n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iEJGD8Pc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZcO2rzWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Nu0nJl06_sendMessage(_c, 0, m);
  cMsg_HVirvI4T_sendMessage(_c, 0, m);
  cMsg_KlVvkGfU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_t02TMW1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_xH8iemen_sendMessage(_c, 0, m);
  cMsg_WuP1wZD3_sendMessage(_c, 0, m);
  cMsg_KlVvkGfU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cXyRxAFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_xH8iemen_sendMessage(_c, 0, m);
  cMsg_HVirvI4T_sendMessage(_c, 0, m);
  cMsg_k4bWekOj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TiTWfVCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vep0YVl8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tmFGeyul_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HrtLgUVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vep0YVl8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tmFGeyul_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_J9gqxuCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RlOL7Zje_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Za0pp5Au_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bf20hACa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RlOL7Zje_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Za0pp5Au_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6SS8URSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v41DXVV7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YvLtinN8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mvX7NR1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v41DXVV7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YvLtinN8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fKosI8v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_HrtLgUVE_sendMessage(_c, 0, m);
  cMsg_bf20hACa_sendMessage(_c, 0, m);
  cMsg_mvX7NR1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sGm7I4Tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_HrtLgUVE_sendMessage(_c, 0, m);
  cMsg_J9gqxuCu_sendMessage(_c, 0, m);
  cMsg_6SS8URSl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_wVGx5juH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_TiTWfVCI_sendMessage(_c, 0, m);
  cMsg_J9gqxuCu_sendMessage(_c, 0, m);
  cMsg_mvX7NR1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_N3fyJ2DN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_oatlBZfY_sendMessage(_c, 0, m);
  cMsg_LVTis2LF_sendMessage(_c, 0, m);
  cMsg_Pe7MLnM8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dBVOOs5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_TiTWfVCI_sendMessage(_c, 0, m);
  cMsg_bf20hACa_sendMessage(_c, 0, m);
  cMsg_6SS8URSl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_xiI9VBKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8QDiETsR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Pn5oFlVx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0Y7lPkw7, 0, m, &cSlice_0Y7lPkw7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sIwRCxA8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_0Y7lPkw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qKJAVm1J_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qKJAVm1J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_R0WM5vhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qKJAVm1J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_qKJAVm1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XL4ZJjT2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_vK2jg8SF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Mem5v5gz, 0, m, &cSlice_Mem5v5gz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_05HgwUE2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Mem5v5gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GUGEOb6U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GUGEOb6U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_NNlttlXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GUGEOb6U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_GUGEOb6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Pj7Pxvn3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_05HgwUE2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ch9781rf, 0, m, &cSlice_Ch9781rf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Pn5oFlVx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Ch9781rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hCMG7tAR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hCMG7tAR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_V9lSIWSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hCMG7tAR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_hCMG7tAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WM1kRosu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_sIwRCxA8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9Cl8XuZf, 0, m, &cSlice_9Cl8XuZf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nA6m6O44_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_9Cl8XuZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZX6ioy8X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZX6ioy8X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_w84mzJw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZX6ioy8X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ZX6ioy8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ystMSJhY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_nA6m6O44_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SgAQaSWG, 0, m, &cSlice_SgAQaSWG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fkLpmsiQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_SgAQaSWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZyHRvSsL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZyHRvSsL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_fxss0hcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZyHRvSsL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ZyHRvSsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AQVAE84k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_jhAUshAh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_buIIAgOd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_buIIAgOd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8jvR1i5E, 1, m, &cDelay_8jvR1i5E_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5jbVHi7T_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8jvR1i5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8jvR1i5E, m);
  cMsg_Xo0MnJAY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_buIIAgOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8jvR1i5E, 0, m, &cDelay_8jvR1i5E_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5jbVHi7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8jvR1i5E, 0, m, &cDelay_8jvR1i5E_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_wHuQ7lUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XuK2Tpu, HV_BINOP_SUBTRACT, 0, m, &cBinop_8XuK2Tpu_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_xFwGNIe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t5eiY2ub_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_TWhc6F7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t5eiY2ub_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_hZ6BEeGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wHuQ7lUt, 0, m, &cVar_wHuQ7lUt_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_GcQWZyl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yzMt6c2C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TT7BJqlq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0skkuDTc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8XuK2Tpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dCAA7d00_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dCAA7d00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HGqtcT6A_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HGqtcT6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_4B0fvkke_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uqBkatbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8z6WrYnA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GaY7dchm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8z6WrYnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xFwGNIe2, 1, m, &cIf_xFwGNIe2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GaY7dchm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_duaTTFj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_fNqDd3G9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TWhc6F7g, 1, m, &cIf_TWhc6F7g_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_duaTTFj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xFwGNIe2, 0, m, &cIf_xFwGNIe2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4B0fvkke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TWhc6F7g, 0, m, &cIf_TWhc6F7g_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TT7BJqlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XuK2Tpu, HV_BINOP_SUBTRACT, 1, m, &cBinop_8XuK2Tpu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0skkuDTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wHuQ7lUt, 0, m, &cVar_wHuQ7lUt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yzMt6c2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cMsg_t5eiY2ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H9nsWpah, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_fkLpmsiQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Yup4ctx3, 0, m, &cSlice_Yup4ctx3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Yup4ctx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zlNMKSPn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zlNMKSPn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_f8l25lBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zlNMKSPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_zlNMKSPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gd5qE81e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_P2BKRnhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_any1DhN1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_YzpqLdtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_79gXzz0V, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_d8O0a8Rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ayzXY4IP, 0, m, &cVar_ayzXY4IP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8QDiETsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lwZXpMjt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_qO2DuGah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jhAUshAh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_V5NjLVit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WWhf5UFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Xo0MnJAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xmS7vKFk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_WWhf5UFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xmS7vKFk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Nr35FRUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_78mJOdvn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_78mJOdvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IXWE0Jtd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_IXWE0Jtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0IZD9JfQ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_2G4iN8Ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MvdJgAg1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_QiLLkxxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dmJBdCMD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_HIwL7ljV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x4f6K95Z_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tv0cBKRx_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dX1jP0M6_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KTLso4rx_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hb8c5xxZ_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P4S8poqL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_x4f6K95Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zb4vsfnj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_tv0cBKRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mCfQ62NG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_dX1jP0M6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GrD9qRrU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_KTLso4rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UNH2l4on_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_hb8c5xxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WariCidQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_P4S8poqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZNFL22wz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_y4NNyDdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3jrVOdgy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Yh9sxxNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_83azqlIQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_0zEXeEwn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hUzz1oDx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hUzz1oDx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_I414hOMG, 1, m, &cDelay_I414hOMG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qJiJZxIp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_I414hOMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I414hOMG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_y4NNyDdd, 0, m, &cIf_y4NNyDdd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hUzz1oDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I414hOMG, 0, m, &cDelay_I414hOMG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qJiJZxIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I414hOMG, 0, m, &cDelay_I414hOMG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aMrVQX39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7BKEPEbh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nE8jwVrO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kQV9KJzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ws4C8tZM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FrBVoZHx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ws4C8tZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y4NNyDdd, 1, m, &cIf_y4NNyDdd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FrBVoZHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0zEXeEwn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_nE8jwVrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yh9sxxNt, 0, m, &cIf_Yh9sxxNt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7BKEPEbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yh9sxxNt, 1, m, &cIf_Yh9sxxNt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_83azqlIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fPNPJGyW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_3jrVOdgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fPNPJGyW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_exxXP2CJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iQaB6Siy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_rROFvAMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fI2mMZy1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_10OUnm5K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hv70rrem_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hv70rrem_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1ia9HI8J, 1, m, &cDelay_1ia9HI8J_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hkIA27PF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_1ia9HI8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1ia9HI8J, m);
  cIf_onMessage(_c, &Context(_c)->cIf_exxXP2CJ, 0, m, &cIf_exxXP2CJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hv70rrem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1ia9HI8J, 0, m, &cDelay_1ia9HI8J_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hkIA27PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1ia9HI8J, 0, m, &cDelay_1ia9HI8J_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6W3p9qRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FipIsiqS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kIf0xoap_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ht6zpxTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CQjJOVZ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8l9Fyxgh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8l9Fyxgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_10OUnm5K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_CQjJOVZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_exxXP2CJ, 1, m, &cIf_exxXP2CJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FipIsiqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rROFvAMz, 1, m, &cIf_rROFvAMz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kIf0xoap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rROFvAMz, 0, m, &cIf_rROFvAMz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fI2mMZy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bUY08gbB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iQaB6Siy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bUY08gbB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2KYvQ741_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I92vb2c3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Y3pPJ2CL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SOTrpS6U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_MrwEJ5mV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_P12MdoeN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_P12MdoeN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jEoE4asv, 1, m, &cDelay_jEoE4asv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kXUOCVsT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_jEoE4asv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jEoE4asv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2KYvQ741, 0, m, &cIf_2KYvQ741_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P12MdoeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jEoE4asv, 0, m, &cDelay_jEoE4asv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kXUOCVsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jEoE4asv, 0, m, &cDelay_jEoE4asv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FqAT2r4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zKjL0gZ9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zmpCfoGN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2CWNgTFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SlqkjJSh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uLHLcAxQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SlqkjJSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2KYvQ741, 1, m, &cIf_2KYvQ741_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uLHLcAxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MrwEJ5mV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zmpCfoGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y3pPJ2CL, 0, m, &cIf_Y3pPJ2CL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zKjL0gZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y3pPJ2CL, 1, m, &cIf_Y3pPJ2CL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SOTrpS6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0V9kHPtS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_I92vb2c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0V9kHPtS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_tQNV46Iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uMOQwUHg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BnBUCRmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BDSjedZg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Xnv3c97B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OoSmUw4y_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OoSmUw4y_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9FpnctNC, 1, m, &cDelay_9FpnctNC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M0lQVCnV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_9FpnctNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9FpnctNC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tQNV46Iq, 0, m, &cIf_tQNV46Iq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OoSmUw4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9FpnctNC, 0, m, &cDelay_9FpnctNC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_M0lQVCnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9FpnctNC, 0, m, &cDelay_9FpnctNC_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7sdtjjly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UK8ywk6Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gm15frF8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_z0WagGna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6wW0daqX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A74nT1WC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_A74nT1WC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Xnv3c97B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_6wW0daqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tQNV46Iq, 1, m, &cIf_tQNV46Iq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Gm15frF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BnBUCRmo, 0, m, &cIf_BnBUCRmo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UK8ywk6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BnBUCRmo, 1, m, &cIf_BnBUCRmo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BDSjedZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xuZ16xNZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_uMOQwUHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xuZ16xNZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_lkx59iKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cK74eulT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ibkkbvHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kTTjS8Ms_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_hQkSaQNr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1NRc7SeW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1NRc7SeW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xiWAeH5v, 1, m, &cDelay_xiWAeH5v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_udpsHcAQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_xiWAeH5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xiWAeH5v, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lkx59iKc, 0, m, &cIf_lkx59iKc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1NRc7SeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xiWAeH5v, 0, m, &cDelay_xiWAeH5v_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_udpsHcAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xiWAeH5v, 0, m, &cDelay_xiWAeH5v_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_38ozxD3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LL7Y9myl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cjzfhgHT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wFcnLzoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CNI3FZdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zv1eJ169_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zv1eJ169_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hQkSaQNr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_CNI3FZdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lkx59iKc, 1, m, &cIf_lkx59iKc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cjzfhgHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ibkkbvHM, 0, m, &cIf_ibkkbvHM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LL7Y9myl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ibkkbvHM, 1, m, &cIf_ibkkbvHM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kTTjS8Ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bHnKG48Q, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_cK74eulT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bHnKG48Q, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_prNeklbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qpIXmshY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_yMiHI3kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nn76nmBN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_qk2JPdta_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UbN0gFz6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UbN0gFz6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tsDidRkU, 1, m, &cDelay_tsDidRkU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XALwLwNL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_tsDidRkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tsDidRkU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_prNeklbh, 0, m, &cIf_prNeklbh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UbN0gFz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tsDidRkU, 0, m, &cDelay_tsDidRkU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XALwLwNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tsDidRkU, 0, m, &cDelay_tsDidRkU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IEtEoShf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FZO5uNzm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e98GtwXm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VzfAZ9EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0cTTWeyh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KZiZyRGJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KZiZyRGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qk2JPdta_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_0cTTWeyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_prNeklbh, 1, m, &cIf_prNeklbh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FZO5uNzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yMiHI3kp, 1, m, &cIf_yMiHI3kp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_e98GtwXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yMiHI3kp, 0, m, &cIf_yMiHI3kp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Nn76nmBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_02VYzb7P, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_qpIXmshY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_02VYzb7P, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_qBW2bReB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OKtjnQ4a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_sRIgef0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rR5K25JX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_WZkBK3R3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_askXBiDG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_askXBiDG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7t5sV2lW, 1, m, &cDelay_7t5sV2lW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5dtkLoKR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7t5sV2lW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7t5sV2lW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qBW2bReB, 0, m, &cIf_qBW2bReB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_askXBiDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7t5sV2lW, 0, m, &cDelay_7t5sV2lW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5dtkLoKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7t5sV2lW, 0, m, &cDelay_7t5sV2lW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nysHRKwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0YhtJcwY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s7ssiVY2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Rh9L5thN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lm9uYTmS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dYvxchEc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dYvxchEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WZkBK3R3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_lm9uYTmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qBW2bReB, 1, m, &cIf_qBW2bReB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0YhtJcwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sRIgef0h, 1, m, &cIf_sRIgef0h_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_s7ssiVY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sRIgef0h, 0, m, &cIf_sRIgef0h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rR5K25JX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4ue4lSvF, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_OKtjnQ4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4ue4lSvF, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_O3Ae2oNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_izDNV1Hy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_1dqQOWsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kjqQhdym_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_tocxwf3s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WAPYDNBP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WAPYDNBP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dSx5CFXq, 1, m, &cDelay_dSx5CFXq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WgJGe5wo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_dSx5CFXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dSx5CFXq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_O3Ae2oNa, 0, m, &cIf_O3Ae2oNa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WAPYDNBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dSx5CFXq, 0, m, &cDelay_dSx5CFXq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WgJGe5wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dSx5CFXq, 0, m, &cDelay_dSx5CFXq_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kG6apA6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ePFGcaMB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wKyY6WJ3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_vYOZgomZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zpqLCnlw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hMpf20cJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hMpf20cJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tocxwf3s_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zpqLCnlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O3Ae2oNa, 1, m, &cIf_O3Ae2oNa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wKyY6WJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1dqQOWsS, 0, m, &cIf_1dqQOWsS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ePFGcaMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1dqQOWsS, 1, m, &cIf_1dqQOWsS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kjqQhdym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rW4YH5IE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_izDNV1Hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rW4YH5IE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_kC6ZF9Cl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dGNSvG89_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_fnXVVnck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1ipgndOW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_n4ymOJS9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oqA7kcYm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oqA7kcYm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EV0jOOc4, 1, m, &cDelay_EV0jOOc4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eWnoAbth_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_EV0jOOc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EV0jOOc4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kC6ZF9Cl, 0, m, &cIf_kC6ZF9Cl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oqA7kcYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EV0jOOc4, 0, m, &cDelay_EV0jOOc4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eWnoAbth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EV0jOOc4, 0, m, &cDelay_EV0jOOc4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sc2AVXG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z7LFTuk5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S5B5kz2p_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_n2uiNqh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0rR0ZkxR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_27bBLwDE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_27bBLwDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_n4ymOJS9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_0rR0ZkxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kC6ZF9Cl, 1, m, &cIf_kC6ZF9Cl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z7LFTuk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fnXVVnck, 1, m, &cIf_fnXVVnck_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_S5B5kz2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fnXVVnck, 0, m, &cIf_fnXVVnck_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1ipgndOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RLpu6t2M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_dGNSvG89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RLpu6t2M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_8bko2MCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3FIENGQY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_sCcdTyzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sR9gk6pp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_NGzNRxKP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qGokgN6m_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qGokgN6m_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ck9zvOWa, 1, m, &cDelay_Ck9zvOWa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a5HxAGxx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Ck9zvOWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ck9zvOWa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8bko2MCA, 0, m, &cIf_8bko2MCA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qGokgN6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ck9zvOWa, 0, m, &cDelay_Ck9zvOWa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_a5HxAGxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ck9zvOWa, 0, m, &cDelay_Ck9zvOWa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ys3q1jif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zx8INiyV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7L7gQ3me_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_R4Oc9YsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VxF06L2L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gsR5CDAI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gsR5CDAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NGzNRxKP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_VxF06L2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8bko2MCA, 1, m, &cIf_8bko2MCA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7L7gQ3me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sCcdTyzS, 0, m, &cIf_sCcdTyzS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Zx8INiyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sCcdTyzS, 1, m, &cIf_sCcdTyzS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sR9gk6pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SxmvnFWt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_3FIENGQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SxmvnFWt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_NiiTqaH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WXTSRAAU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_6vPoIKop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qXRjerv4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_OSjdg3HC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aLVX85ez_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aLVX85ez_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JjCFpnrn, 1, m, &cDelay_JjCFpnrn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LZtH6au5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_JjCFpnrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JjCFpnrn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NiiTqaH3, 0, m, &cIf_NiiTqaH3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aLVX85ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JjCFpnrn, 0, m, &cDelay_JjCFpnrn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LZtH6au5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JjCFpnrn, 0, m, &cDelay_JjCFpnrn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XRfoscdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XV7xnygX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vFJOoqTr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LR7nCCVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JqGkLjSI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z3eN3I7O_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z3eN3I7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OSjdg3HC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_JqGkLjSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NiiTqaH3, 1, m, &cIf_NiiTqaH3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vFJOoqTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vPoIKop, 0, m, &cIf_6vPoIKop_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XV7xnygX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vPoIKop, 1, m, &cIf_6vPoIKop_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qXRjerv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7YdlIHTh, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_WXTSRAAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7YdlIHTh, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_AeYVTHY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AP0VMoLW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_zx9mxmqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_84oMzxQO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_7dc9CECk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TtCSnrkx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TtCSnrkx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DP7nRLf9, 1, m, &cDelay_DP7nRLf9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R1MwX4GW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_DP7nRLf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DP7nRLf9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AeYVTHY7, 0, m, &cIf_AeYVTHY7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TtCSnrkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DP7nRLf9, 0, m, &cDelay_DP7nRLf9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_R1MwX4GW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DP7nRLf9, 0, m, &cDelay_DP7nRLf9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JopVKxi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DGEOiy2s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s56VV0P2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cyUPRF8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_67NSwvy3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KIjE4D4w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KIjE4D4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7dc9CECk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_67NSwvy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AeYVTHY7, 1, m, &cIf_AeYVTHY7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_s56VV0P2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zx9mxmqq, 0, m, &cIf_zx9mxmqq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DGEOiy2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zx9mxmqq, 1, m, &cIf_zx9mxmqq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_84oMzxQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vUsIeJ7q, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AP0VMoLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vUsIeJ7q, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_zb4vsfnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_yJdbgqTR_sendMessage(_c, 0, m);
  cMsg_AoGfayvY_sendMessage(_c, 0, m);
  cMsg_S5JWJUO6_sendMessage(_c, 0, m);
  cMsg_SuvKgQmI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_mCfQ62NG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_yJdbgqTR_sendMessage(_c, 0, m);
  cMsg_1DSK571h_sendMessage(_c, 0, m);
  cMsg_MHEMwD7B_sendMessage(_c, 0, m);
  cMsg_KcBaw1xW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_GrD9qRrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_bLHoKwtK_sendMessage(_c, 0, m);
  cMsg_1DSK571h_sendMessage(_c, 0, m);
  cMsg_SuvKgQmI_sendMessage(_c, 0, m);
  cMsg_zNPWMEQu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_UNH2l4on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_bLHoKwtK_sendMessage(_c, 0, m);
  cMsg_eQ4nwVeA_sendMessage(_c, 0, m);
  cMsg_S5JWJUO6_sendMessage(_c, 0, m);
  cMsg_mLF0w4o2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WariCidQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_Vk8Anvor_sendMessage(_c, 0, m);
  cMsg_KcBaw1xW_sendMessage(_c, 0, m);
  cMsg_bXmfKmhD_sendMessage(_c, 0, m);
  cMsg_S5JWJUO6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZNFL22wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_Vk8Anvor_sendMessage(_c, 0, m);
  cMsg_mLF0w4o2_sendMessage(_c, 0, m);
  cMsg_1DSK571h_sendMessage(_c, 0, m);
  cMsg_YVXWoL8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4VSeD8gN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kQV9KJzk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aMrVQX39_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Q21PUuQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kQV9KJzk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aMrVQX39_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vToEmxNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ht6zpxTs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6W3p9qRh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4Yx1z1Ga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ht6zpxTs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6W3p9qRh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_e8t0Jqap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2CWNgTFW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FqAT2r4G_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TOpLKPis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2CWNgTFW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FqAT2r4G_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yJdbgqTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_4VSeD8gN_sendMessage(_c, 0, m);
  cMsg_4Yx1z1Ga_sendMessage(_c, 0, m);
  cMsg_TOpLKPis_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bLHoKwtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Q21PUuQL_sendMessage(_c, 0, m);
  cMsg_vToEmxNz_sendMessage(_c, 0, m);
  cMsg_TOpLKPis_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Vk8Anvor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Q21PUuQL_sendMessage(_c, 0, m);
  cMsg_4Yx1z1Ga_sendMessage(_c, 0, m);
  cMsg_e8t0Jqap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_X89WeZFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z0WagGna_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7sdtjjly_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VnCXDIqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z0WagGna_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7sdtjjly_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DahWNv8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wFcnLzoz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_38ozxD3V_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7U4qb3ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wFcnLzoz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_38ozxD3V_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_T7EqrIrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VzfAZ9EY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IEtEoShf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zkTlqjNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VzfAZ9EY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IEtEoShf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1DSK571h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_VnCXDIqG_sendMessage(_c, 0, m);
  cMsg_7U4qb3ew_sendMessage(_c, 0, m);
  cMsg_zkTlqjNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_AoGfayvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_VnCXDIqG_sendMessage(_c, 0, m);
  cMsg_DahWNv8j_sendMessage(_c, 0, m);
  cMsg_T7EqrIrD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eQ4nwVeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_X89WeZFX_sendMessage(_c, 0, m);
  cMsg_7U4qb3ew_sendMessage(_c, 0, m);
  cMsg_T7EqrIrD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KbENV0lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R4Oc9YsY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ys3q1jif_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_88a2xinh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R4Oc9YsY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ys3q1jif_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Sro3ydn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LR7nCCVY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRfoscdO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_e7r8BXl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LR7nCCVY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRfoscdO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XCriiTUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cyUPRF8G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JopVKxi5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1nDUHrNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cyUPRF8G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JopVKxi5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mLF0w4o2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_KbENV0lv_sendMessage(_c, 0, m);
  cMsg_e7r8BXl8_sendMessage(_c, 0, m);
  cMsg_1nDUHrNb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KcBaw1xW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_88a2xinh_sendMessage(_c, 0, m);
  cMsg_Sro3ydn8_sendMessage(_c, 0, m);
  cMsg_1nDUHrNb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_SuvKgQmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_88a2xinh_sendMessage(_c, 0, m);
  cMsg_e7r8BXl8_sendMessage(_c, 0, m);
  cMsg_XCriiTUB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MuhJ5f8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Rh9L5thN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nysHRKwl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AGquwsjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Rh9L5thN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nysHRKwl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8g0O89lR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vYOZgomZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kG6apA6h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ln0kBbUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vYOZgomZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kG6apA6h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DefwmKF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n2uiNqh5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sc2AVXG5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lHbi9zkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n2uiNqh5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sc2AVXG5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_S5JWJUO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_AGquwsjr_sendMessage(_c, 0, m);
  cMsg_Ln0kBbUP_sendMessage(_c, 0, m);
  cMsg_lHbi9zkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MHEMwD7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_AGquwsjr_sendMessage(_c, 0, m);
  cMsg_8g0O89lR_sendMessage(_c, 0, m);
  cMsg_DefwmKF3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_YVXWoL8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_MuhJ5f8r_sendMessage(_c, 0, m);
  cMsg_8g0O89lR_sendMessage(_c, 0, m);
  cMsg_lHbi9zkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bXmfKmhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_X89WeZFX_sendMessage(_c, 0, m);
  cMsg_DahWNv8j_sendMessage(_c, 0, m);
  cMsg_zkTlqjNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zNPWMEQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_MuhJ5f8r_sendMessage(_c, 0, m);
  cMsg_Ln0kBbUP_sendMessage(_c, 0, m);
  cMsg_DefwmKF3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_6KaNLRCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aU0CItUp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_NJWbcgMk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TQ1g076G, 0, m, &cSlice_TQ1g076G_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Sy0V3NOi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_TQ1g076G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Rq1X7MAL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Rq1X7MAL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_VjGLpYnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Rq1X7MAL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Rq1X7MAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jdk32CbN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_IRYBcRIp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k1rogUTI, 0, m, &cSlice_k1rogUTI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mx1uw2Lw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_k1rogUTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8QEwCRck_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8QEwCRck_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_AmjluGZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8QEwCRck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_8QEwCRck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cJXugHDZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_mx1uw2Lw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7HuvFQJW, 0, m, &cSlice_7HuvFQJW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NJWbcgMk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_7HuvFQJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2kjNdqlx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2kjNdqlx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_StdK4x6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2kjNdqlx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_2kjNdqlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eolSktLE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Sy0V3NOi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v3noEVM8, 0, m, &cSlice_v3noEVM8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BULKVfGB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_v3noEVM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iy1QL65f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iy1QL65f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_pfWqiiht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iy1QL65f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_iy1QL65f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_71dRqySV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_BULKVfGB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IgGf7JC9, 0, m, &cSlice_IgGf7JC9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0ipjyie1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_IgGf7JC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mnLI2i4Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mnLI2i4Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_PcNy5saT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mnLI2i4Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_mnLI2i4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BeqylVJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_CkfZrj7U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_T8qeYYNN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_T8qeYYNN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9buI2Jv3, 1, m, &cDelay_9buI2Jv3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EpbhQgYE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_9buI2Jv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9buI2Jv3, m);
  cMsg_jcdoX8gL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_T8qeYYNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9buI2Jv3, 0, m, &cDelay_9buI2Jv3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EpbhQgYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9buI2Jv3, 0, m, &cDelay_9buI2Jv3_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_SOsLxY8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RlMfDkiK, HV_BINOP_SUBTRACT, 0, m, &cBinop_RlMfDkiK_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_PKFkXslv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zMTsUCGU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Hsfg0nhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zMTsUCGU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_VWutT7Sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SOsLxY8P, 0, m, &cVar_SOsLxY8P_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_mxEwZxcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fs0SPmX2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yuzj7IfP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yBcJa66o_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RlMfDkiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f8hCE4ah_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_f8hCE4ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MOD70his_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MOD70his_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_bjuwQ4zc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5UTDoS5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oew6PPGI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xKzCkn2F_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xKzCkn2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wsqnaVAM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Oew6PPGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PKFkXslv, 1, m, &cIf_PKFkXslv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_07MxuKmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hsfg0nhU, 1, m, &cIf_Hsfg0nhU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wsqnaVAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PKFkXslv, 0, m, &cIf_PKFkXslv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_bjuwQ4zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hsfg0nhU, 0, m, &cIf_Hsfg0nhU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yBcJa66o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SOsLxY8P, 0, m, &cVar_SOsLxY8P_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yuzj7IfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RlMfDkiK, HV_BINOP_SUBTRACT, 1, m, &cBinop_RlMfDkiK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fs0SPmX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cMsg_zMTsUCGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dyoGFs8w, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_0ipjyie1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4ulwkrSU, 0, m, &cSlice_4ulwkrSU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_4ulwkrSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5BBkdpkc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5BBkdpkc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_zlyVeeTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5BBkdpkc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_5BBkdpkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H7kMEkCV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MvdJgAg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q4idMazn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_dmJBdCMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9PnsaXLK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_4LXB6YFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QiLLkxxw, 0, m, &cVar_QiLLkxxw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aU0CItUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AaWbo4ff, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_fsnHPyrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ywOE4LHb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_xzgqLwFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CkfZrj7U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jcdoX8gL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W4e98D1u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ywOE4LHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W4e98D1u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BtdCghxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_xjyEf9Ls_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xjyEf9Ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f0AhaWig_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_f0AhaWig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pGF5NdiP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_4IPIu9LD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0EXezegB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5Nwo2M8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uzbIycN0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_j9S88t6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zn5jNzhS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_9bKKlrOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8jhkGuqj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KuOsJ6V2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vK2jg8SF_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_IRYBcRIp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Ggv2Mwr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vK2jg8SF_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_IRYBcRIp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_bAqLpD8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PBhfuJdR, 0, m, &cVar_PBhfuJdR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DY0yxwek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vK2jg8SF_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_IRYBcRIp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7x4lS1We_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vK2jg8SF_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_IRYBcRIp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Que0Z7jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vK2jg8SF_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_IRYBcRIp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7bMhi3KP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_HHPFw2ZR, 0, m, &cVar_HHPFw2ZR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QRWDt2ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_vabyJzPM, 0, m, &cVar_vabyJzPM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YDeQggF1, 0, m, &cVar_YDeQggF1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ll2PUTYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bAqLpD8d_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rn5HZ7U3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YCbGicVQ, 0, m, &cVar_YCbGicVQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0EXezegB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vK2jg8SF_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_IRYBcRIp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_RIDcyZel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4IPIu9LD, 0, m, &cVar_4IPIu9LD_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_8jhkGuqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Nr69qoj8_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Vq213T30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iw2xByEx, 0, m, &cVar_Iw2xByEx_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_F7LHr8Rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bAqLpD8d_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ohxPTldk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HHPFw2ZR, 0, m, &cVar_HHPFw2ZR_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_6SWlUiNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R0WM5vhA, 0, m, &cVar_R0WM5vhA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NNlttlXt, 0, m, &cVar_NNlttlXt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_V9lSIWSh, 0, m, &cVar_V9lSIWSh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w84mzJw1, 0, m, &cVar_w84mzJw1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fxss0hcu, 0, m, &cVar_fxss0hcu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_f8l25lBk, 0, m, &cVar_f8l25lBk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VjGLpYnU, 0, m, &cVar_VjGLpYnU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AmjluGZ8, 0, m, &cVar_AmjluGZ8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_StdK4x6M, 0, m, &cVar_StdK4x6M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pfWqiiht, 0, m, &cVar_pfWqiiht_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PcNy5saT, 0, m, &cVar_PcNy5saT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zlyVeeTe, 0, m, &cVar_zlyVeeTe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KrNYgQbH_sendMessage);
  cMsg_rn5HZ7U3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_UXKUOMBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YCbGicVQ, 0, m, &cVar_YCbGicVQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_w3wNuyhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vabyJzPM, 0, m, &cVar_vabyJzPM_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_fuA4Ihjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YDeQggF1, 0, m, &cVar_YDeQggF1_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_XL4ZJjT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E68j1GGs, 0, m, &cVar_E68j1GGs_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ystMSJhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xiI9VBKw, 0, m, &cVar_xiI9VBKw_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_WM1kRosu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_d8O0a8Rg_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Pj7Pxvn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Giac9akq_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V5NjLVit_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qO2DuGah_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_AQVAE84k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uqBkatbH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fNqDd3G9_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_gd5qE81e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nr35FRUC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_Jdk32CbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2G4iN8Ng, 0, m, &cVar_2G4iN8Ng_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_71dRqySV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6KaNLRCB, 0, m, &cVar_6KaNLRCB_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_eolSktLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_4LXB6YFN_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_cJXugHDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HIwL7ljV_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fsnHPyrz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xzgqLwFt_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_BeqylVJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5UTDoS5y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_07MxuKmp_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_H7kMEkCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BtdCghxU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_DzRtXQ1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4IPIu9LD, 0, m, &cVar_4IPIu9LD_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_8Ix9ZFRe, VIf(I0));
    __hv_varread_f(&sVarf_7RnU7Sxk, VOf(Bf0));
    __hv_varread_f(&sVarf_pWXaPSO2, VOf(Bf1));
    __hv_varread_f(&sVarf_a20U7JUW, VOf(Bf2));
    __hv_varread_f(&sVarf_BuaMkvST, VOf(Bf3));
    __hv_varread_f(&sVarf_eUg5J4Cx, VOf(Bf4));
    __hv_varread_f(&sVarf_MQDKBrt1, VOf(Bf5));
    __hv_varread_f(&sVarf_X3Wtv5Bn, VOf(Bf6));
    __hv_varwrite_f(&sVarf_9CcLSjVF, VIf(I0));
    __hv_varread_f(&sVarf_8Ehd4SL4, VOf(Bf7));
    __hv_line_f(&sLine_ZedT4dfA, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_96P43WAX, VOf(Bf9));
    __hv_line_f(&sLine_OelE5ZIq, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_6YSqWAWi, VOf(Bf8));
    __hv_line_f(&sLine_V1awk77X, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_BuaMkvST, VIf(Bf11));
    __hv_varread_f(&sVarf_9CcLSjVF, VOf(Bf11));
    __hv_line_f(&sLine_xTHm8405, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_0S8PHxDj, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_7dMwlPgM, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_eUg5J4Cx, VIf(Bf10));
    __hv_line_f(&sLine_bOI8r0Fb, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_hKzntOW2, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_fK0ZAw2E, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_MQDKBrt1, VIf(Bf10));
    __hv_line_f(&sLine_44b8sFzs, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_laRLDJZs, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_bgQ3dpax, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_X3Wtv5Bn, VIf(Bf10));
    __hv_varwrite_f(&sVarf_8Ehd4SL4, VIf(Bf0));
    __hv_varwrite_f(&sVarf_96P43WAX, VIf(Bf1));
    __hv_varwrite_f(&sVarf_6YSqWAWi, VIf(Bf2));
    sEnv_process(this, &sEnv_hZ6BEeGo, VIf(Bf3), &sEnv_hZ6BEeGo_sendMessage);
    sEnv_process(this, &sEnv_GcQWZyl5, VIf(I0), &sEnv_GcQWZyl5_sendMessage);
    __hv_line_f(&sLine_H9nsWpah, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_xmS7vKFk, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_0IZD9JfQ, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_aTGz6zaK, VOf(Bf3));
    __hv_line_f(&sLine_79gXzz0V, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_7RnU7Sxk, VIf(Bf0));
    __hv_varwrite_f(&sVarf_aTGz6zaK, VIf(Bf4));
    __hv_varwrite_f(&sVarf_vUV78xU0, VIf(Bf5));
    __hv_varwrite_f(&sVarf_ZTiWCWGO, VIf(Bf6));
    __hv_varread_f(&sVarf_ZTiWCWGO, VOf(Bf6));
    __hv_line_f(&sLine_lwZXpMjt, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_a20U7JUW, VIf(Bf4));
    __hv_varread_f(&sVarf_vUV78xU0, VOf(Bf4));
    __hv_line_f(&sLine_any1DhN1, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_pWXaPSO2, VIf(Bf4));
    __hv_varwrite_f(&sVarf_nwq4K5ct, VIf(Bf2));
    __hv_varwrite_f(&sVarf_H9dQbnc0, VIf(I1));
    __hv_varread_f(&sVarf_I6ORl4ul, VOf(Bf2));
    __hv_varread_f(&sVarf_DEeW7kdf, VOf(Bf4));
    __hv_varread_f(&sVarf_YskWwFYt, VOf(Bf0));
    __hv_varread_f(&sVarf_oy0ypEXO, VOf(Bf5));
    __hv_varread_f(&sVarf_a10KTZ2X, VOf(Bf3));
    __hv_varread_f(&sVarf_VIla07Rj, VOf(Bf6));
    __hv_varread_f(&sVarf_ZR40llXo, VOf(Bf1));
    __hv_varwrite_f(&sVarf_k5cJpGI3, VIf(I1));
    __hv_varread_f(&sVarf_R6DjHrch, VOf(Bf10));
    __hv_line_f(&sLine_SxmvnFWt, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_uIwgTzQ6, VOf(Bf7));
    __hv_line_f(&sLine_7YdlIHTh, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Qz5CfA9P, VOf(Bf11));
    __hv_line_f(&sLine_vUsIeJ7q, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_oy0ypEXO, VIf(Bf12));
    __hv_varread_f(&sVarf_k5cJpGI3, VOf(Bf12));
    __hv_line_f(&sLine_fPNPJGyW, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_xuZ16xNZ, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_4ue4lSvF, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_a10KTZ2X, VIf(Bf9));
    __hv_line_f(&sLine_bUY08gbB, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_bHnKG48Q, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_rW4YH5IE, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_VIla07Rj, VIf(Bf9));
    __hv_line_f(&sLine_0V9kHPtS, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_02VYzb7P, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_RLpu6t2M, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_ZR40llXo, VIf(Bf9));
    __hv_varwrite_f(&sVarf_R6DjHrch, VIf(Bf2));
    __hv_varwrite_f(&sVarf_uIwgTzQ6, VIf(Bf4));
    __hv_varwrite_f(&sVarf_Qz5CfA9P, VIf(Bf0));
    sEnv_process(this, &sEnv_VWutT7Sg, VIf(Bf5), &sEnv_VWutT7Sg_sendMessage);
    sEnv_process(this, &sEnv_mxEwZxcw, VIf(I1), &sEnv_mxEwZxcw_sendMessage);
    __hv_line_f(&sLine_dyoGFs8w, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_W4e98D1u, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_pGF5NdiP, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_krkrSHvM, VOf(Bf5));
    __hv_line_f(&sLine_9PnsaXLK, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_I6ORl4ul, VIf(Bf2));
    __hv_varwrite_f(&sVarf_krkrSHvM, VIf(Bf3));
    __hv_varwrite_f(&sVarf_9V0X997h, VIf(Bf6));
    __hv_varwrite_f(&sVarf_UByJFqWu, VIf(Bf1));
    __hv_varread_f(&sVarf_UByJFqWu, VOf(Bf1));
    __hv_line_f(&sLine_AaWbo4ff, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_YskWwFYt, VIf(Bf3));
    __hv_varread_f(&sVarf_9V0X997h, VOf(Bf3));
    __hv_line_f(&sLine_q4idMazn, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_DEeW7kdf, VIf(Bf3));
    __hv_varwrite_f(&sVarf_cPbAPxeD, VIf(Bf0));
    __hv_varread_f(&sVarf_H9dQbnc0, VOf(Bf0));
    __hv_line_f(&sLine_zn5jNzhS, VOf(Bf3));
    __hv_varread_f(&sVarf_cPbAPxeD, VOf(Bf2));
    __hv_line_f(&sLine_uzbIycN0, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_8Ix9ZFRe, VOf(Bf2));
    __hv_varread_f(&sVarf_nwq4K5ct, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
